/**
 * GMyth Library
 *
 * @file gmyth/gmyth_http.c
 * 
 * @brief <p> GMythHttp class provides a wrapper to access
 * data from the database using http+xml
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Artur Duque de Souza <@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GMYTH_HTTP_H__
#define __GMYTH_HTTP_H__

#include <glib-object.h>

#include "gmyth_socket.h"
#include "gmyth_backendinfo.h"

#define BUFLEN 1024

G_BEGIN_DECLS

#define GMYTH_HTTP_TYPE               (gmyth_http_get_type ())
#define GMYTH_HTTP(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_HTTP_TYPE, GMythHttp))
#define GMYTH_HTTP_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_HTTP_TYPE, GMythHttpClass))
#define IS_GMYTH_HTTP(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_HTTP_TYPE))
#define IS_GMYTH_HTTP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_HTTP_TYPE))
#define GMYTH_HTTP_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GMYTH_HTTP_TYPE, GMythHttpClass))

#define MYTH_PORT_STATUS 6544

typedef struct _GMythHttp         GMythHttp;
typedef struct _GMythHttpClass    GMythHttpClass;

struct _GMythHttpClass
{
  GObjectClass parent_class;

  /* callbacks */
  /* no one for now */
};

struct _GMythHttp
{
    GObject parent;
  
    GMythBackendInfo *backend_info;
    GMythSocket *socket;

    GString *opt_socket_name; /* socket name (use built-in value) */
    unsigned int opt_flags; /* connection flags (none) */
};


GType gmyth_http_get_type (void);

GMythHttp* gmyth_http_new ();
GString* gmyth_http_request (GMythHttp *gmyth_http, GString *command);

G_END_DECLS

#endif /* __GMYTH_HTTP_H__ */
